/*
 * class VidWriter
 *
 * $Date$
 * $Revision$
 *
 */

#ifndef VID_WRITER_HH__
#define VID_WRITER_HH__

#include "WImage/VideoWriter.hh"

/** 
 * @addtogroup WImage 
 * @{ */

/**
 * A VID video file writer. Dimensions are known from the {\em Image}
 * object. 
 */
class 
VidWriter: public VideoWriter
{
public:
  
  /** Constructor. Only calls the mother class' constructor to initialize
   * the {\em ImageArray} reference and set the offset if necessary. 
   * @param name
   * the file name
   * @param arrays
   * the array of video arrays for the values  
   * @param colors the number of colors
   * @param skip the size of the header to fill with zeros before the actual
   * contents */
  VidWriter (char const *name, VideoArray < coeff > *arrays[], 
             int colors, int skip)
    : VideoWriter (name, arrays, colors) { m_skip = skip; }

  /** Destructor - does nothing. */
  virtual ~VidWriter (void) {}

protected: 
  /** Write a VID video file. This is the method that does the actual
   * work. It will be called by the {\em write ()} method.
   * @return 
   * 0 if successful, -1 on write error. */
  virtual int writefmt (void);
  /** The number of bytes before the contents */
  int m_skip;
}; /* class VidWriter */

/** @} */

#endif /* VID_WRITER_HH__ */
